==> edge-login-ui-rn-2.16.0.tgz: package/lib/actions/LoginCompleteActions.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { Keyboard } from 'react-native';
import { sprintf } from 'sprintf-js';
import { lstrings } from '../common/locales/strings';
import { ButtonsModal } from '../components/modals/ButtonsModal';
import { Airship } from '../components/services/AirshipInstance';
import * as Constants from '../constants/index';
import { enableTouchId, isTouchDisabled, isTouchEnabled, supportsTouchId } from '../keychain';
import { hasSecurityAlerts } from '../util/hasSecurityAlerts';
/**
 * The user has just logged in, so figure out what do to next.
 */
export const completeLogin = (account) => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    // Problem logins:
    const { skipSecurityAlerts = false } = imports;
    if (!skipSecurityAlerts && hasSecurityAlerts(account)) {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'securityAlert', params: { account } }
        });
        return;
    }
    // Recovery logins:
    if (account.recoveryLogin) {
        yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, message: lstrings.recovery_successful, buttons: { ok: { label: lstrings.ok } } })));
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'resecurePassword', params: { account } }
        });
        return;
    }
    // Normal logins:
    yield twofaReminder(account);
    dispatch(submitLogin(account));
});
/**
 * Everything is done, and we can pass the account to the outside world.
 */
export const submitLogin = (account) => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    const { onLogin } = imports;
    account.watch('loggedIn', loggedIn => {
        if (!loggedIn)
            dispatch({ type: 'RESET_APP' });
    });
    const touchDisabled = yield isTouchDisabled(account);
    if (!touchDisabled) {
        yield enableTouchId(account).catch(e => {
            console.log(e); // Fail quietly
        });
    }
    const isTouchSupported = yield supportsTouchId();
    const touchEnabled = yield isTouchEnabled(account);
    const touchIdInformation = {
        isTouchSupported,
        isTouchEnabled: touchEnabled
    };
    if (onLogin != null)
        onLogin(account, touchIdInformation);
    // Hide all modals and scenes:
    Airship.clear();
    dispatch({ type: 'NAVIGATE', data: { name: 'loading', params: '' } });
});
function twofaReminder(account) {
    return __awaiter(this, void 0, void 0, function* () {
        const { otpKey, dataStore, username } = account;
        if (username == null)
            return;
        const pluginList = yield dataStore.listStoreIds();
        const storeName = pluginList.includes(Constants.OTP_REMINDER_STORE_NAME)
            ? Constants.OTP_REMINDER_STORE_NAME
            : null;
        const itemList = storeName
            ? yield dataStore.listItemIds(Constants.OTP_REMINDER_STORE_NAME)
            : null;
        const createdAtString = itemList && itemList.includes(Constants.OTP_REMINDER_KEY_NAME_CREATED_AT)
            ? yield dataStore.getItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_CREATED_AT)
            : null;
        const createdAt = createdAtString ? parseInt(createdAtString) : null;
        const reminderCreatedAtDate = createdAt
            ? createdAt + Constants.OTP_REMINDER_MILLISECONDS
            : null;
        const lastOtpCheckString = itemList &&
            itemList.includes(Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED)
            ? yield dataStore.getItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED)
            : null;
        const lastOtpCheck = lastOtpCheckString ? parseInt(lastOtpCheckString) : null;
        const reminderLastOtpCheckDate = lastOtpCheck
            ? lastOtpCheck + Constants.OTP_REMINDER_MILLISECONDS
            : null;
        const dontAsk = itemList && itemList.includes(Constants.OTP_REMINDER_KEY_NAME_DONT_ASK)
            ? yield dataStore.getItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_DONT_ASK)
            : null;
        const enableOtp = (account) => __awaiter(this, void 0, void 0, function* () {
            yield account.enableOtp();
            return yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: lstrings.otp_authentication_header, message: sprintf(lstrings.otp_authentication_message, account.otpKey), buttons: { ok: { label: lstrings.ok } } })));
        });
        const createOtpCheckModal = () => __awaiter(this, void 0, void 0, function* () {
            Keyboard.dismiss();
            const result = yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: lstrings.otp_reset_modal_header, message: lstrings.otp_reset_modal_message, buttons: {
                    yes: { label: lstrings.enable },
                    no: { label: lstrings.skip_button, type: 'secondary' }
                } })));
            return result === 'yes';
        });
        const createOtpCheckModalDontAsk = () => __awaiter(this, void 0, void 0, function* () {
            Keyboard.dismiss();
            return yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: lstrings.otp_reset_modal_header, message: lstrings.otp_reset_modal_message, buttons: {
                    enable: { label: lstrings.enable, type: 'primary' },
                    cancel: { label: lstrings.skip_button, type: 'secondary' },
                    dontAsk: {
                        label: lstrings.otp_reset_modal_dont_ask,
                        type: 'secondary'
                    }
                } })));
        });
        if (otpKey) {
            return true;
        }
        if (dontAsk) {
            return true;
        }
        if (!storeName) {
            const resolve = yield createOtpCheckModal();
            if (resolve) {
                yield enableOtp(account);
                yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED, Date.now().toString());
                return true;
            }
            yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED, Date.now().toString());
            return false;
        }
        if (lastOtpCheckString &&
            lastOtpCheck &&
            reminderLastOtpCheckDate &&
            Date.now() > reminderLastOtpCheckDate) {
            const resolve = yield createOtpCheckModalDontAsk();
            if (resolve === 'enable') {
                yield enableOtp(account);
                return true;
            }
            if (resolve === 'dontAsk') {
                yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_DONT_ASK, 'true');
                return false;
            }
            yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED, Date.now().toString());
            return false;
        }
        if (lastOtpCheckString) {
            return true;
        }
        if (createdAtString &&
            createdAt &&
            reminderCreatedAtDate &&
            Date.now() > reminderCreatedAtDate) {
            const resolve = yield createOtpCheckModal();
            if (resolve) {
                yield enableOtp(account);
                yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED, Date.now().toString());
                return true;
            }
            yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED, Date.now().toString());
            return false;
        }
        return true;
    });
}

==> edge-login-ui-rn-3.3.1.tgz: package/lib/actions/LoginCompleteActions.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { Keyboard } from 'react-native';
import { sprintf } from 'sprintf-js';
import { lstrings } from '../common/locales/strings';
import { ButtonsModal } from '../components/modals/ButtonsModal';
import { Airship } from '../components/services/AirshipInstance';
import * as Constants from '../constants/index';
import { enableTouchId, isTouchDisabled, isTouchEnabled, supportsTouchId } from '../keychain';
import { hasSecurityAlerts } from '../util/hasSecurityAlerts';
import { checkAndRequestNotifications } from './LoginInitActions';
/**
 * The user has just logged in, so figure out what do to next.
 */
export const completeLogin = (account) => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    // Problem logins:
    const { skipOtpReminder = false, skipSecurityAlerts = false } = imports;
    if (!skipSecurityAlerts && hasSecurityAlerts(account)) {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'securityAlert', params: { account } }
        });
        return;
    }
    // Recovery logins:
    if (account.recoveryLogin) {
        yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, message: lstrings.recovery_successful, buttons: { ok: { label: lstrings.ok } } })));
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'resecurePassword', params: { account } }
        });
        return;
    }
    // Normal logins:
    if (!skipOtpReminder) {
        yield twofaReminder(account);
    }
    dispatch(submitLogin(account));
});
/**
 * Everything is done, and we can pass the account to the outside world.
 */
export const submitLogin = (account) => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    const { onLogin } = imports;
    account.watch('loggedIn', loggedIn => {
        if (!loggedIn)
            dispatch({ type: 'RESET_APP' });
    });
    const touchDisabled = yield isTouchDisabled(account);
    if (!touchDisabled) {
        yield enableTouchId(account).catch(e => {
            console.log(e); // Fail quietly
        });
    }
    const isTouchSupported = yield supportsTouchId();
    const touchEnabled = yield isTouchEnabled(account);
    const touchIdInformation = {
        isTouchSupported,
        isTouchEnabled: touchEnabled
    };
    if (onLogin != null)
        onLogin(account, touchIdInformation);
    if (imports.customPermissionsFunction != null) {
        imports.customPermissionsFunction();
    }
    else {
        yield dispatch(checkAndRequestNotifications((_a = imports.branding) !== null && _a !== void 0 ? _a : {})).catch(error => console.log(error));
    }
    // Hide all modals and scenes:
    Airship.clear();
    dispatch({ type: 'NAVIGATE', data: { name: 'loading', params: '' } });
});
function twofaReminder(account) {
    return __awaiter(this, void 0, void 0, function* () {
        const { otpKey, dataStore, username } = account;
        if (username == null)
            return;
        const pluginList = yield dataStore.listStoreIds();
        const storeName = pluginList.includes(Constants.OTP_REMINDER_STORE_NAME)
            ? Constants.OTP_REMINDER_STORE_NAME
            : null;
        const itemList = storeName
            ? yield dataStore.listItemIds(Constants.OTP_REMINDER_STORE_NAME)
            : null;
        const createdAtString = itemList && itemList.includes(Constants.OTP_REMINDER_KEY_NAME_CREATED_AT)
            ? yield dataStore.getItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_CREATED_AT)
            : null;
        const createdAt = createdAtString ? parseInt(createdAtString) : null;
        const reminderCreatedAtDate = createdAt
            ? createdAt + Constants.OTP_REMINDER_MILLISECONDS
            : null;
        const lastOtpCheckString = itemList &&
            itemList.includes(Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED)
            ? yield dataStore.getItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED)
            : null;
        const lastOtpCheck = lastOtpCheckString ? parseInt(lastOtpCheckString) : null;
        const reminderLastOtpCheckDate = lastOtpCheck
            ? lastOtpCheck + Constants.OTP_REMINDER_MILLISECONDS
            : null;
        const dontAsk = itemList && itemList.includes(Constants.OTP_REMINDER_KEY_NAME_DONT_ASK)
            ? yield dataStore.getItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_DONT_ASK)
            : null;
        const enableOtp = (account) => __awaiter(this, void 0, void 0, function* () {
            yield account.enableOtp();
            return yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: lstrings.otp_authentication_header, message: sprintf(lstrings.otp_authentication_message, account.otpKey), buttons: { ok: { label: lstrings.ok } } })));
        });
        const createOtpCheckModal = () => __awaiter(this, void 0, void 0, function* () {
            Keyboard.dismiss();
            const result = yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: lstrings.otp_reset_modal_header, message: lstrings.otp_reset_modal_message, buttons: {
                    yes: { label: lstrings.enable },
                    no: { label: lstrings.skip_button, type: 'secondary' }
                } })));
            return result === 'yes';
        });
        const createOtpCheckModalDontAsk = () => __awaiter(this, void 0, void 0, function* () {
            Keyboard.dismiss();
            return yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: lstrings.otp_reset_modal_header, message: lstrings.otp_reset_modal_message, buttons: {
                    enable: { label: lstrings.enable, type: 'primary' },
                    cancel: { label: lstrings.skip_button, type: 'secondary' },
                    dontAsk: {
                        label: lstrings.otp_reset_modal_dont_ask,
                        type: 'secondary'
                    }
                } })));
        });
        if (otpKey) {
            return true;
        }
        if (dontAsk) {
            return true;
        }
        if (!storeName) {
            const resolve = yield createOtpCheckModal();
            if (resolve) {
                yield enableOtp(account);
                yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED, Date.now().toString());
                return true;
            }
            yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED, Date.now().toString());
            return false;
        }
        if (lastOtpCheckString &&
            lastOtpCheck &&
            reminderLastOtpCheckDate &&
            Date.now() > reminderLastOtpCheckDate) {
            const resolve = yield createOtpCheckModalDontAsk();
            if (resolve === 'enable') {
                yield enableOtp(account);
                return true;
            }
            if (resolve === 'dontAsk') {
                yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_DONT_ASK, 'true');
                return false;
            }
            yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED, Date.now().toString());
            return false;
        }
        if (lastOtpCheckString) {
            return true;
        }
        if (createdAtString &&
            createdAt &&
            reminderCreatedAtDate &&
            Date.now() > reminderCreatedAtDate) {
            const resolve = yield createOtpCheckModal();
            if (resolve) {
                yield enableOtp(account);
                yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED, Date.now().toString());
                return true;
            }
            yield account.dataStore.setItem(Constants.OTP_REMINDER_STORE_NAME, Constants.OTP_REMINDER_KEY_NAME_LAST_OTP_CHECKED, Date.now().toString());
            return false;
        }
        return true;
    });
}
